==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced.md <==
# AwsShieldAwsShieldAdvanced


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')
```



| Illustration | AwsShieldAwsShieldAdvanced | AwsShieldAwsShieldAdvancedCard | AwsShieldAwsShieldAdvancedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced.png) | ![illustration for AwsShieldAwsShieldAdvanced](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced.Local.png) | ![illustration for AwsShieldAwsShieldAdvancedCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvancedCard.Local.png) | ![illustration for AwsShieldAwsShieldAdvancedGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvancedGroup.Local.png) |




## AwsShieldAwsShieldAdvanced

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvanced
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvanced('AwsShieldAwsShieldAdvanced', 'Aws Shield Aws Shield Advanced', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvanced
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvanced('AwsShieldAwsShieldAdvanced', 'Aws Shield Aws Shield Advanced', 'an optional tech label')
@enduml
```

## AwsShieldAwsShieldAdvancedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedCard('AwsShieldAwsShieldAdvancedCard', 'Aws Shield Aws Shield Advanced Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedCard('AwsShieldAwsShieldAdvancedCard', 'Aws Shield Aws Shield Advanced Card', 'an optional description')
@enduml
```

## AwsShieldAwsShieldAdvancedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedGroup('AwsShieldAwsShieldAdvancedGroup', 'Aws Shield Aws Shield Advanced Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedGroup('AwsShieldAwsShieldAdvancedGroup', 'Aws Shield Aws Shield Advanced Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced.md <==
# AwsShieldAwsShieldAdvanced


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')
```



| Illustration | AwsShieldAwsShieldAdvanced | AwsShieldAwsShieldAdvancedCard | AwsShieldAwsShieldAdvancedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced.png) | ![illustration for AwsShieldAwsShieldAdvanced](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced.Local.png) | ![illustration for AwsShieldAwsShieldAdvancedCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvancedCard.Local.png) | ![illustration for AwsShieldAwsShieldAdvancedGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvancedGroup.Local.png) |




## AwsShieldAwsShieldAdvanced

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvanced
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvanced('AwsShieldAwsShieldAdvanced', 'Aws Shield Aws Shield Advanced', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvanced
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvanced('AwsShieldAwsShieldAdvanced', 'Aws Shield Aws Shield Advanced', 'an optional tech label')
@enduml
```

## AwsShieldAwsShieldAdvancedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedCard('AwsShieldAwsShieldAdvancedCard', 'Aws Shield Aws Shield Advanced Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedCard('AwsShieldAwsShieldAdvancedCard', 'Aws Shield Aws Shield Advanced Card', 'an optional description')
@enduml
```

## AwsShieldAwsShieldAdvancedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedGroup('AwsShieldAwsShieldAdvancedGroup', 'Aws Shield Aws Shield Advanced Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsShieldAwsShieldAdvancedGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsShieldAwsShieldAdvanced')

' renders the element
AwsShieldAwsShieldAdvancedGroup('AwsShieldAwsShieldAdvancedGroup', 'Aws Shield Aws Shield Advanced Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
